@@ -25,20 +25,20 @@ $file =~ s/\s+$//;
 
 cmpthese timethese -1 => {
 	':reverse' => sub{
-		open my $in, '<:unix:reverse', $file or die $!;
+		open my $in, '<:reverse', $file or die $!;
 		while(<$in>){
 			#...;
 		}
 	},
 
 	'reverse readline' => sub{
-		open my $in, '<:unix:perlio', $file or die $!;
+		open my $in, '<:perlio', $file or die $!;
 		foreach (reverse <$in>){
 			# ...
 		}
 	},
 	'readline' => sub{
-		open my $in, '<:unix:perlio', $file or die $!;
+		open my $in, '<:perlio', $file or die $!;
 		while(<$in>){
 			# ...
 		}
